# Skanym

This repository contains The core fonctionalities to create, edit and export 3D animations using the skeletal animation principle.

## Wikis

- [Motion Machine](https://gitlab-etu.ing.he-arc.ch/groups/isc/general/motion-machine/-/wikis/home)

- [Skanym](https://gitlab-etu.ing.he-arc.ch/isc/general/motion-machine/skanym-package/-/wikis/home)






